@@ -37,8 +37,8 @@ class ScheduleStatus(NamedTuple):
 
 
 class VortaScheduler(QtCore.QObject):
-    #: The schedule for the profile with the given id changed.
-    schedule_changed = QtCore.pyqtSignal(int)
+    #: The schedule for a profile changed.
+    schedule_changed = QtCore.pyqtSignal()
 
     def __init__(self):
         super().__init__()
@@ -196,6 +196,7 @@ class VortaScheduler(QtCore.QObject):
         next suitable backup time.
         """
         profile = BackupProfileModel.get_or_none(id=profile_id)
+        logger.debug('Profile: %s, %d %d', str(profile), profile.schedule_fixed_hour, profile.schedule_fixed_minute)
         if profile is None:  # profile doesn't exist any more.
             return
 
@@ -222,13 +223,13 @@ class VortaScheduler(QtCore.QObject):
                     profile_id,
                 )
                 # Emit signal so that e.g. the GUI can react to the new schedule
-                self.schedule_changed.emit(profile_id)
+                self.schedule_changed.emit()
                 return
 
             if profile.schedule_mode == 'off':
                 logger.debug('Scheduler for profile %s is disabled.', profile_id)
                 # Emit signal so that e.g. the GUI can react to the new schedule
-                self.schedule_changed.emit(profile_id)
+                self.schedule_changed.emit()
                 return
 
             logger.info('Setting timer for profile %s', profile_id)
@@ -267,7 +268,7 @@ class VortaScheduler(QtCore.QObject):
                 )
                 self.timers[profile_id] = {'type': ScheduleStatusType.NO_PREVIOUS_BACKUP}
                 # Emit signal so that e.g. the GUI can react to the new schedule
-                self.schedule_changed.emit(profile_id)
+                self.schedule_changed.emit()
                 return
 
             # calculate next scheduled time
@@ -291,6 +292,8 @@ class VortaScheduler(QtCore.QObject):
                 # unknown schedule mode
                 raise ValueError("Unknown schedule mode '{}'".format(profile.schedule_mode))
 
+            logger.debug('Last run time: %s', last_time)
+
             # handle missing of a scheduled time
             if next_time <= dt.now():
                 if profile.schedule_make_up_missed:
@@ -356,7 +359,7 @@ class VortaScheduler(QtCore.QObject):
                 }
 
         # Emit signal so that e.g. the GUI can react to the new schedule
-        self.schedule_changed.emit(profile_id)
+        self.schedule_changed.emit()
 
     def reload_all_timers(self):
         logger.debug('Refreshing all scheduler timers')
